Enum Encoding Copy item path Source pub enum Encoding {
Mono,
MonoA,
Palette4,
Palette8,
Mask8,
RLE24,
JP2PNG,
ARGB,
}Expand description Methods of encoding an image within an icon element.
Each IconType uses a particular encoding within
an ICNS file; this type enumerates those encodings.
(This type is used internally by the library, but is irrelvant to most
library users; if you’re not sure whether you need to use it, you probably
don’t.)
Icon element data payload is an uncompressed one bit image
Icon element data payload is an uncompressed one bit image with a one bit mask
Icon element data payload is an uncompressed image with a fixed 4-bit color palette
Icon element data payload is an uncompressed image with a fixed 8-bit color palette
Icon element data payload is an uncompressed 8-bit alpha mask.
Icon element data payload is an RLE-compressed 24-bit RGB image.
Icon element data payload is a JPEG 2000 or PNG file.
Icon element data payload is typically an RLE-compressed 32-bit ARGB image,
but may also contain a JPEG 2000 or PNG file.
Performs copy-assignment from
source.
Read more Formats the value using the given formatter.
Read more Compares and returns the maximum of two values.
Read more Compares and returns the minimum of two values.
Read more Restrict a value to a certain interval.
Read more 🔬 This is a nightly-only experimental API. (clamp_to)
Restrict a value to a certain range.
Read more This method returns an ordering between
self and
other values if one exists.
Read more Tests less than (for
self and
other) and is used by the
< operator.
Read more Tests less than or equal to (for
self and
other) and is used by the
<= operator.
Read more Tests greater than (for
self and
other) and is used by the
>
operator.
Read more Tests greater than or equal to (for
self and
other) and is used by
the
>= operator.
Read more Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more 🔬 This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From <T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more Uses borrowed data to replace owned data, usually by cloning.
Read more The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.